@@ -9,7 +9,7 @@ from . import utils, atomic, atmos
 
 def synthesize(teff,logg,mh=0.0,am=0.0,cm=0.0,nm=0.0,vmicro=2.0,elems=None,
                wrange=[15000.0,17000.0],dw=0.1,atmod=None,atmos_type='kurucz',
-               dospherical=True,linelist=None,solarisotopes=False,workdir=None,
+               dospherical=True,linelists=None,solarisotopes=False,workdir=None,
                save=False,verbose=False):
     """
     Code to synthesize a spectrum with MOOG.
@@ -44,8 +44,8 @@ def synthesize(teff,logg,mh=0.0,am=0.0,cm=0.0,nm=0.0,vmicro=2.0,elems=None,
        Type of model atmosphere file.  Default is 'kurucz'.
     dospherical : bool, optional
        Perform spherically-symmetric calculations (otherwise plane-parallel).  Default is True.
-    linelist : str
-       Linelist filename.
+    linelists : list
+       List of linelist file names.
     save : bool, optional
        Save temporary directory and files for synthesis.  Default=False.
     workdir : str, optional
@@ -103,11 +103,11 @@ def synthesize(teff,logg,mh=0.0,am=0.0,cm=0.0,nm=0.0,vmicro=2.0,elems=None,
                       atmos.cval(mh), atmos.cval(am), atmos.cval(cm), atmos.cval(nm),atmos.cval(vmicro))
 
     # Check that linelists and model atmosphere files exit
-    #if type(linelists) is str:
-    #    linelists = [linelists]
-    #for l in linelists:
-    if os.path.exists(linelist)==False:
-        raise FileNotFoundError(l)
+    if type(linelists) is str:
+        linelists = [linelists]
+    for l in linelists:
+        if os.path.exists(l)==False:
+            raise FileNotFoundError(l)
     if os.path.exists(atmod)==False:
         raise FileNotFoundError(atmod)
 
@@ -115,7 +115,7 @@ def synthesize(teff,logg,mh=0.0,am=0.0,cm=0.0,nm=0.0,vmicro=2.0,elems=None,
         spherical= True
     else:
         spherical = False
-    flux,cont,wave = do_moog(root,atmod,linelist,mh,am,abundances,wrange,dw,
+    flux,cont,wave = do_moog(root,atmod,linelists,mh,am,abundances,wrange,dw,
                              save=save,solarisotopes=solarisotopes)
 
     os.chdir(cwd)
@@ -130,7 +130,7 @@ def synthesize(teff,logg,mh=0.0,am=0.0,cm=0.0,nm=0.0,vmicro=2.0,elems=None,
     return flux,cont,wave
 
     
-def do_moog(root,atmod,linefile,mh,am,abundances,wrange,dw,
+def do_moog(root,atmod,linelists,mh,am,abundances,wrange,dw,
             solarisotopes=False,spherical=True,vmicro=2.0,
             molecules=None,save=False,verbose=False):
     """
@@ -142,8 +142,8 @@ def do_moog(root,atmod,linefile,mh,am,abundances,wrange,dw,
        Root of filenames to use for this MOOG run.
     atmod : str, optional
        Name of atmosphere model (default=None, model is determined from input parameters).
-    linefile : str
-       Linelist filename.
+    linelists : list
+       List of linelist file names.
     mh : float, optional
        Metallicity, [M/H].  Default is 0.0 (solar).
     am : float, optional
@@ -275,19 +275,30 @@ def do_moog(root,atmod,linefile,mh,am,abundances,wrange,dw,
     w1 = wrange[1]
     fwhm = 0.01  # Gaussian broadening 
      
-    # Read in the linelist
-    linelist = utils.readlines(linefile,comment='#')
-    nlinelist = len(linelist)
-    lwave = np.array([float(l.split()[0]) for l in linelist]).astype(float)
+    # Read in the linelists
+    lines = []
+    for i in range(len(linelists)):
+        lines1 = utils.readlines(linelists[i],noblank=True)  #,comment='#')
+        lines += lines1
+    nlinelist = len(lines)
+    # Get wavelengths
+    lwave = np.array([float(l.split()[0]) for l in lines]).astype(float)
+    # Sort the lines if more than one linelist was input
+    if len(linelists)>1:
+        si = np.argsort(lwave)
+        lwave = lwave[si]
+        lines = np.char.array(lines)[si]
+    else:
+        lines = np.char.array(lines)        
     wavemin = np.min(lwave) 
     wavemax = np.max(lwave) 
     
     # Make temporary linelist file 
     tid,templist = tempfile.mkstemp(prefix='line')
     templist = os.path.basename(templist)
-    gd, = np.where((lwave >= w0) & (lwave <= w1))
-    tlinelist = np.char.array(linelist)[gd]
-    utils.writelines(templist,tlinelist)
+    gd, = np.where((lwave >= (w0-1)) & (lwave <= (w1+1)))  # allow 1A buffer on ends
+    tlines = np.char.array(lines)[gd]
+    utils.writelines(templist,tlines)
          
     # This is what the MOOG input file looks like 
     #terminal       'xterm' 
